@@ -96,7 +96,7 @@ public final class Services {
     public static <S extends Object> S getService(final Class<? extends S> clazz) {
         final com.openexchange.server.ServiceLookup serviceLookup = REF.get();
         if (null == serviceLookup) {
-            throw new IllegalStateException("Missing ServiceLookup instance. Bundle \"com.openexchange.ajp13\" not started?");
+            throw new IllegalStateException("Missing ServiceLookup instance. Bundle \"com.openexchange.unifiedinbox\" not started?");
         }
         return serviceLookup.getService(clazz);
     }
